# db2clean.ps1
# For use with Stelo Data Replicator (SQDR)
# Copyright 2024 StarQuest Ventures, Inc. 

# Edit the list of database names as appropriate
#
# This may be invoked as a scheduled task (Windows) or by crontab (Linux).
#
# On Windows, this must be invoked from an elevated command window ("Run with highest authorities" in Windows scheduled task)
# as it uses db2hadr
# Alternatively, you can select the options to clean based on the date rather than the output of db2hadr
#
# Choose whether to 
#   * Use the MON_GET_HADR table function to determine the STANDBY_LOG_TIME (deleting all archive logs that are prior to that)
#         (this only works on HADR databases)
#   * run daily (deleting all archive logs previous to the current day)
#   * run monthly (deleting all archive logs previous to the current month)
#
# This script should be run as a user with sufficient authority to connect to the database and run prune history
# If desired, you can specify credentials in this script
#
# This script will succeed only on the current primary system as it needs to connect to the database.
#

# Customize these values
$dbnames = 'SQDRC', 'SQDRP0', 'SQDRP1'
$user='sqdr'
$password='sqdrplus'
$hadr = $true

set-item -path env:DB2CLP -value "**$$**"

# If you are not using HADR, uncomment one of the following blocks:

# The following will clean logs older than the current month
# You can schedule this task to run monthly on the last day of the month.
# $day='01' 
# $month=Get-Date -Format "yyyyMM" 
# $date = ($month) + ($day)
# $hadr=$false

# OR
# The following will clean logs older than the current day
# You can schedule this task to run daily shortly before midnight
# $date=Get-Date -Format "yyyyMMddHH" 
# $hadr=$false


foreach ($dbname in $dbnames)
{
    write-host $dbname
    db2 connect to $dbname user $user using $password
   if ($hadr)
   {
# Use the MON_GET_HADR table function to determine the STANDBY_LOG_TIME
	$sql = "SELECT MIN(VARCHAR_FORMAT(STANDBY_LOG_TIME, 'YYYYMMDDHH24MI')) from table(MON_GET_HADR(NULL))"
	$standby_log_time =  ( db2 -t -x $sql  )
	$standby_log_time
	$date=$standby_log_time[-2]
    }

    write-host "Cleaning archive logs older than $date"

    db2 prune history $date with force option and delete
    db2 disconnect $dbname
}


